resource "openstack_compute_keypair_v2" "test-keypair" {
  name       = "my-keypair"
  public_key = "${file("~/.ssh/id_rsa.pub")}"
}

#local variable for ssh connect to ohpc
locals {
  connection = {
    host        = "${format("164.111.161.%s", element(split(".", openstack_networking_floatingip_v2.ip_pool.address),3))}"
    user        = "centos"
    private_key = "${file("~/.ssh/id_rsa")}"
  }
}

# creates dmznet
resource "openstack_networking_network_v2" "dmznet" {
  name           = "dmznet"
  admin_state_up = "true"
}

resource "openstack_networking_subnet_v2" "dmzsubnet" {
  name            = "dmzsubnet"
  network_id      = "${openstack_networking_network_v2.dmznet.id}"
  cidr            = "192.168.100.0/24"
  ip_version      = 4
  dns_nameservers = ["8.8.8.8"]
  enable_dhcp = true
}

# defines the router borderrouter using floating ip defined in datasources.tf to create the external network id
resource "openstack_networking_router_v2" "borderrouter" {
  name                = "borderrouter"
  admin_state_up      = "true"
  external_network_id = "${data.openstack_networking_network_v2.borderrouter.id}"
}

resource "openstack_networking_router_interface_v2" "borderrouter" {
  router_id = "${openstack_networking_router_v2.borderrouter.id}"
  subnet_id = "${openstack_networking_subnet_v2.dmzsubnet.id}"
}


# creates clusternet
resource "openstack_networking_network_v2" "clusternet" {
  name           = "clusternet"
  admin_state_up = "true"
}
# creates clustersubnet
# cidr is the subnet range (that subnet range and dns nameservers from the network create file in feat-openstack)
resource "openstack_networking_subnet_v2" "clustersubnet" {
  name            = "clustersubnet"
  network_id      = "${openstack_networking_network_v2.clusternet.id}"
  cidr            = "10.1.1.0/24"
  ip_version      = 4
  enable_dhcp     = false
}


# defines where floating ip will come from using variable from vars.tf
resource "openstack_networking_floatingip_v2" "ip_pool" {
  pool = "${var.pool}"
}

# creates details for the OHPC instance using variables defined in vars.tf
resource "openstack_compute_instance_v2" "ohpc" {
depends_on = ["openstack_networking_subnet_v2.dmzsubnet"]
  name            = "ohpc"
  image_name      = "${var.image}"
  flavor_name     = "${var.flavor}"
  key_pair        = "${openstack_compute_keypair_v2.openstack.key_name}"
  security_groups = ["default"]

# defines the networks of the instance
  network {
    name = "dmznet"
  }
  network {
    name = "clusternet"
  }
}

# associates floating ip with the OHPC instance and run the ansible playbook
resource "openstack_compute_floatingip_associate_v2" "ohpc" {
  floating_ip = "${openstack_networking_floatingip_v2.ip_pool.address}"
  instance_id = "${openstack_compute_instance_v2.ohpc.id}"

  provisioner "remote-exec" {
    connection {
      host    =  "${format("164.111.161.%s", element(split(".", openstack_networking_floatingip_v2.ip_pool.address),3))}"
      user        = "centos"
      private_key = "${file("~/.ssh/id_rsa")}"
    }

    inline = [
      "sudo mkdir -p /CRI_XCBC && sudo chown centos: /CRI_XCBC",
      "sudo yum install -y epel-release",
      "sudo yum install -y ansible git vim bash-completion",
      "sudo yum install -y NetworkManager",
      "sudo systemctl restart NetworkManager",
      "sudo nmcli con mod 'Wired connection 1' connection.id 'eth1'"
    ]
  }

  provisioner "file" {
    source      = "CRI_XCBC/"
    destination = "/CRI_XCBC/"
    connection {
      host    =  "${format("164.111.161.%s", element(split(".", openstack_networking_floatingip_v2.ip_pool.address),3))}"
      #host        = "${openstack_networking_floatingip_v2.terraform.address}"
      user        = "centos"
      private_key = "${file("~/.ssh/id_rsa")}"
    }
  }

  provisioner "remote-exec" {
    connection {
      host    =  "${format("164.111.161.%s", element(split(".", openstack_networking_floatingip_v2.ip_pool.address),3))}"
      #host        = "${openstack_networking_floatingip_v2.ohpc.address}"
      user        = "centos"
      private_key = "${file("~/.ssh/id_rsa")}"
    }
    inline = [
      "sudo ansible-playbook -c local -i /CRI_XCBC/hosts -l `hostname -s` /CRI_XCBC/site.yaml -b"
    ]
  }
}
